%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% BuildOriMoveTable() builds the orientation movement table oriMoveTable as
%   a global variable. For a given orientation rank i (0 <= i < 6^3), the
%   table gives the its j-neighbour (1 <= j <= 9) orientation's rank. j
%   represents a rotation, where j = 1,...,9 means a single turn of U, U2, 
%   Ui, R, R2, Ri, F, F2, Fi, respectively. The size of oriMoveTable is
%   (6^3)-by-9.
% 
% The rank of an orientation is the number in base 10 which the orientation
%   represents in base 3 with its digits (least significant first).
% 
% This function uses: ORotate()
% This function used in: BuildOptimalTable(), Solve()
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
function [] = BuildOriMoveTable()

global oriMoveTable;

ROWNUM = power(3,6);
oriMoveTable = -1*ones(ROWNUM,9);

% for every entry in the table
for on = 0:ROWNUM-1
        
    % Calculate the (on-1)-th permutation
    % (-1 because of matrix indexing)
    oriRank = on;
    ori = zeros(1,7);
    ori(6) = floor(oriRank/243); oriRank = mod(oriRank,243);
    ori(5) = floor(oriRank/81);  oriRank = mod(oriRank,81);
    ori(4) = floor(oriRank/27);  oriRank = mod(oriRank,27);
    ori(3) = floor(oriRank/9);   oriRank = mod(oriRank,9);
    ori(2) = floor(oriRank/3);   oriRank = mod(oriRank,3);
    ori(1) = oriRank;
    ori(7) = mod(3-sum(ori),3);
    
    % For every neighbour
    for move = 1:9
        % move-neighbour orientation
        oriNew = ORotate(ori,move);
        % Calculate its rank
        oriNewRank =    oriNew(1) +  3*oriNew(2) +  9*oriNew(3) + ...
                     27*oriNew(4) + 81*oriNew(5)+ 243*oriNew(6);
        % Update table
        % (Don't forget to shift by 1 because of matrix indexing)
        oriMoveTable(on+1,move) = oriNewRank;

    end
end

end
