%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% ORotate() applies a single rotation on a cube orientation, resulting an
%   other cube orientation.
% 
% Input:
%   ori - a cube orientation: a 1-by-7 matrix with 0-s, 1-s and 2-s
%   rotation - a single rotation: a whole number between 0 and 9, where
%       U = 1, U2 = 2, Ui = 3, R = 4, R2 = 5, Ri = 6, F = 7, F2 = 8, Fi = 9
% 
% Output:
%   oriNew - a cube orientation: a 1-by-7 matrix with 0-s, 1-s and 2-s
%
% Used functions: -
% 
% Example (an Ri rotation on a cube where the first cubie oriented CW, the
%   second cubie oriented CCW):
%   oriNew = ORotate([1 2 0 0 0 0 0], 6);
% 
% This function uses: -
% This function used in: Scramble(), BuildOriMoveTable()
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
function oriNew = ORotate(ori, rotation)

% Define rotations
U = 1; U2 = 2; Ui = 3;
R = 4; R2 = 5; Ri = 6;
F = 7; F2 = 8; Fi = 9;

% Define cubie positions
ULB = 1; UBR = 2; URF = 3; UFL = 4;
DRB = 5; DFR = 6; DLF = 7;

% The new cube orientation
oriNew = ori;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% APPLY U* ROTATIONS
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
if rotation == U
    
    oriNew(ULB) = ori(UFL);
    oriNew(UFL) = ori(URF);
    oriNew(URF) = ori(UBR);
    oriNew(UBR) = ori(ULB);
    
elseif rotation == U2
    
    oriNew(ULB) = ori(URF);
    oriNew(UBR) = ori(UFL);
    oriNew(URF) = ori(ULB);
    oriNew(UFL) = ori(UBR);
    
elseif rotation == Ui
    
    oriNew(ULB) = ori(UBR);
    oriNew(UBR) = ori(URF);
    oriNew(URF) = ori(UFL);
    oriNew(UFL) = ori(ULB);
    
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% APPLY R* ROTATIONS
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
elseif rotation == R
    
    oriNew(UBR) = mod(ori(URF) + 1, 3);
    oriNew(URF) = mod(ori(DFR) + 2, 3);
    oriNew(DFR) = mod(ori(DRB) + 1, 3);
    oriNew(DRB) = mod(ori(UBR) + 2, 3);
    
elseif rotation == R2
    
    oriNew(UBR) = ori(DFR);
    oriNew(DFR) = ori(UBR);
    oriNew(URF) = ori(DRB);
    oriNew(DRB) = ori(URF);
    
elseif rotation == Ri
    
    oriNew(UBR) = mod(ori(DRB) + 1, 3);
    oriNew(DRB) = mod(ori(DFR) + 2, 3);
    oriNew(DFR) = mod(ori(URF) + 1, 3);
    oriNew(URF) = mod(ori(UBR) + 2, 3);
    
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% APPLY F* ROTATIONS
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
elseif rotation == F
    
    oriNew(URF) = mod(ori(UFL) + 1, 3);
    oriNew(UFL) = mod(ori(DLF) + 2, 3);
    oriNew(DLF) = mod(ori(DFR) + 1, 3);
    oriNew(DFR) = mod(ori(URF) + 2, 3);
    
elseif rotation == F2
    
    oriNew(URF) = ori(DLF);
    oriNew(DLF) = ori(URF);
    oriNew(UFL) = ori(DFR);
    oriNew(DFR) = ori(UFL);
    
elseif rotation == Fi
    
    oriNew(URF) = mod(ori(DFR) + 1, 3);
    oriNew(DFR) = mod(ori(DLF) + 2, 3);
    oriNew(DLF) = mod(ori(UFL) + 1, 3);
    oriNew(UFL) = mod(ori(URF) + 2, 3);
    
else
    error('Rotation error');
end

end
