%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% OptimalDistance() gives the optimal distance (mod 3) from the solved
%   state for a given cube's ordinal number.
% 
% This function requires an existing optimalTable, which contains the
%   compressed distance values (modulo 3) for all possible cube state. By
%   default, the optimalTable is loaded from optimalTable.mat. If the
%   optimalTable is missing, you can generate it with BuildOptimalTable().
% 
% Input:
%   ord - the ordinal number of a cube: a number between 1 and 7!*3^6. ord
%   is the rank of the cube + 1.
% 
% Output:
%   dist - the distance from the solved state (modulo 3): 0, 1 or 2.
%
% This function uses: -
% This function used in: Solve()
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
function dist = OptimalDistance(ord)

global optimalTable;

% If optimalTable doesn't exist, load it from optimalTable.mat
if isempty(optimalTable)
    load('optimalTable.mat');
end

% row is row number of ord in optimalTable
row = floor((ord-1)/5)+1;
% num shows which element of the 5 successive cases is ord
num = mod(ord-1,5)+1;

% Load the number from optimalTable: it is a number in base 10. Type
%   conversion is needed for avoiding overflow
number = double(optimalTable(row));
% number contains 5 successive distances; we need the num-th.
for i = 1:num
    dist = floor(number/power(3,5-i));
    number = mod(number,power(3,5-i));
end

end
