%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% PRotate() applies a single rotation on a cube permutation, resulting an
%   other cube permutation.
%
% Input:
%   perm - a cube permutation: a permutation of the [1 2 3 4 5 6 7] matrix
%   rotation - a single rotation: a whole number between 0 and 9, where
%       U = 1, U2 = 2, Ui = 3, R = 4, R2 = 5, Ri = 6, F = 7, F2 = 8, Fi = 9
% 
% Output:
%   permNew - a cube permutation: a permutation of the [1 2 3 4 5 6 7]
%       matrix
%
% Used functions: -
% 
% Example (an Ri rotation on a cube where the first two pieces are swapped)
%   permNew = PRotate([2 1 3 4 5 6 7], 6);
% 
% This function uses: -
% This function used in: Scramble(), BuildPermMoveTable()
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
function permNew = PRotate(perm, rotation)

% Define rotations
U = 1; U2 = 2; Ui = 3;
R = 4; R2 = 5; Ri = 6;
F = 7; F2 = 8; Fi = 9;

% Define cubie positions
ULB = 1; UBR = 2; URF = 3; UFL = 4;
DRB = 5; DFR = 6; DLF = 7;

% The new cube permutation
permNew = perm;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% APPLY U* ROTATIONS
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
if rotation == U
    
    permNew(ULB) = perm(UFL);
    permNew(UFL) = perm(URF);
    permNew(URF) = perm(UBR);    
    permNew(UBR) = perm(ULB);
    
elseif rotation == U2
    
    permNew(ULB) = perm(URF);
    permNew(URF) = perm(ULB);
    permNew(UBR) = perm(UFL);
    permNew(UFL) = perm(UBR);
    
elseif rotation == Ui
    
    permNew(ULB) = perm(UBR);
    permNew(UBR) = perm(URF);
    permNew(URF) = perm(UFL);
    permNew(UFL) = perm(ULB);
    
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% APPLY R* ROTATIONS
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
elseif rotation == R
    
    permNew(UBR) = perm(URF);
    permNew(URF) = perm(DFR);
    permNew(DFR) = perm(DRB);
    permNew(DRB) = perm(UBR);
    
elseif rotation == R2
    
    permNew(UBR) = perm(DFR);
    permNew(DFR) = perm(UBR);
    permNew(URF) = perm(DRB);
    permNew(DRB) = perm(URF);
    
elseif rotation == Ri
    
    permNew(UBR) = perm(DRB);
    permNew(DRB) = perm(DFR);
    permNew(DFR) = perm(URF);
    permNew(URF) = perm(UBR);
    
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% APPLY F* ROTATIONS
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
elseif rotation == F
    
    permNew(URF) = perm(UFL);
    permNew(UFL) = perm(DLF);
    permNew(DLF) = perm(DFR);
    permNew(DFR) = perm(URF);
    
elseif rotation == F2
    
    permNew(URF) = perm(DLF);
    permNew(DLF) = perm(URF);
    permNew(UFL) = perm(DFR);
    permNew(DFR) = perm(UFL);
    
elseif rotation == Fi
    
    permNew(URF) = perm(DFR);
    permNew(DFR) = perm(DLF);
    permNew(DLF) = perm(UFL);
    permNew(UFL) = perm(URF);
    
else
    error('Rotation error');
end

end
