%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Scramble() scrambles the solved cube according to a series of rotations.
% 
% Input:
%   rotationStr - a string contains the rotations separated with spaces.
%       A string can contain only U, U2, Ui, R, R2, Ri, F, F2, Fi.
% 
% Output:
%   cube - a cube state representing the scramble: a 2-by-7 matrix
%
% Used functions: Protate(), ORotate()
% 
% Example:
%   cubeState = Scramble('R U2 Fi Ui R');
% 
% This function uses: PRotate(), ORotate()
% This function used in: -
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
function cubeState = Scramble(rotationStr)

% Define rotations
U = 1; U2 = 2; Ui = 3;
R = 4; R2 = 5; Ri = 6;
F = 7; F2 = 8; Fi = 9;

% First row contains permutations, second row contains orientations
PERM = 1; ORIE = 2;

% Start from the solved cube
cubeState = [1 2 3 4 5 6 7;
             0 0 0 0 0 0 0 ];

if isempty(rotationStr)
    error('Empty Rotation String!');
end

% While we have something in the string
while(true)
    
    % Cut out the first rotation
    [rotation, remainingStr] = strtok(rotationStr);
    
    % Apply the rotation on the cube
    if isequal(rotation,'U')
        cubeState(PERM,:) = PRotate(cubeState(PERM,:), U);
        cubeState(ORIE,:) = ORotate(cubeState(ORIE,:), U);
    elseif isequal(rotation,'U2')
        cubeState(PERM,:) = PRotate(cubeState(PERM,:), U2);
        cubeState(ORIE,:) = ORotate(cubeState(ORIE,:), U2);
    elseif isequal(rotation,'Ui')
        cubeState(PERM,:) = PRotate(cubeState(PERM,:), Ui);
        cubeState(ORIE,:) = ORotate(cubeState(ORIE,:), Ui);
    elseif isequal(rotation,'R')
        cubeState(PERM,:) = PRotate(cubeState(PERM,:), R);
        cubeState(ORIE,:) = ORotate(cubeState(ORIE,:), R);
    elseif isequal(rotation,'R2')
        cubeState(PERM,:) = PRotate(cubeState(PERM,:), R2);
        cubeState(ORIE,:) = ORotate(cubeState(ORIE,:), R2);
    elseif isequal(rotation,'Ri')
        cubeState(PERM,:) = PRotate(cubeState(PERM,:), Ri);
        cubeState(ORIE,:) = ORotate(cubeState(ORIE,:), Ri);
    elseif isequal(rotation,'F')
        cubeState(PERM,:) = PRotate(cubeState(PERM,:), F);
        cubeState(ORIE,:) = ORotate(cubeState(ORIE,:), F);
    elseif isequal(rotation,'F2')
        cubeState(PERM,:) = PRotate(cubeState(PERM,:), F2);
        cubeState(ORIE,:) = ORotate(cubeState(ORIE,:), F2);
    elseif isequal(rotation,'Fi')
        cubeState(PERM,:) = PRotate(cubeState(PERM,:), Fi);
        cubeState(ORIE,:) = ORotate(cubeState(ORIE,:), Fi);
    else error('Scramble error');
    end
    
    % If nothing left, we are finished
    if isempty(remainingStr)
        break;
    end
    % Else: continue the process with the remaining string
    rotationStr = remainingStr;
    
end